==> aria2-0.4.1.tar.bz2: aria2-0.4.1/src/MultiDiskWriter.h <==
/* <!-- copyright */
/*
 * aria2 - a simple utility for downloading files faster
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* copyright --> */
#ifndef _D_MULTI_DISK_WRITER_H_
#define _D_MULTI_DISK_WRITER_H_

#include "DefaultDiskWriter.h"
#include "TorrentMan.h"
#include "messageDigest.h"

class DiskWriterEntry {
public:
  FileEntry fileEntry;
  DiskWriter* diskWriter;
public:
  DiskWriterEntry(const FileEntry& fileEntry):fileEntry(fileEntry) {
    diskWriter = new DefaultDiskWriter(this->fileEntry.length);
  }
  ~DiskWriterEntry() {
    delete diskWriter;
  }
};

typedef deque<DiskWriterEntry*> DiskWriterEntries;

class MultiDiskWriter : public DiskWriter {
private:
  DiskWriterEntries diskWriterEntries;
  int pieceLength;
  bool isInRange(const DiskWriterEntry* entry, long long int offset) const;
  int calculateLength(const DiskWriterEntry* entry, long long int fileOffset, int rem) const;
  void clearEntries();
#ifdef ENABLE_SHA1DIGEST
  MessageDigestContext ctx;
  void hashUpdate(DiskWriterEntry* entry, long long int offset, long long int length);
#endif // ENABLE_SHA1DIGEST

public:
  MultiDiskWriter(int pieceLength);
  virtual ~MultiDiskWriter();

  void setFileEntries(const FileEntries& fileEntries);

  virtual void openFile(const string& filename);
  virtual void initAndOpenFile(const string& filename);
  virtual void closeFile();
  virtual void openExistingFile(const string& filename);
  virtual void writeData(const char* data, int len, long long int position = 0);
  virtual int readData(char* data, int len, long long int position);
  virtual string sha1Sum(long long int offset, long long int length);
};

#endif // _D_MULTI_DISK_WRITER_H_

==> aria2-0.6.0.tar.bz2: aria2-0.6.0/src/MultiDiskWriter.h <==
/* <!-- copyright */
/*
 * aria2 - a simple utility for downloading files faster
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* copyright --> */
#ifndef _D_MULTI_DISK_WRITER_H_
#define _D_MULTI_DISK_WRITER_H_

#include "DefaultDiskWriter.h"
#include "TorrentMan.h"
#include "messageDigest.h"

class DiskWriterEntry {
public:
  FileEntry fileEntry;
  DiskWriter* diskWriter;
public:
  DiskWriterEntry(const FileEntry& fileEntry):fileEntry(fileEntry) {
    diskWriter = new DefaultDiskWriter(this->fileEntry.length);
  }
  ~DiskWriterEntry() {
    delete diskWriter;
  }
};

typedef deque<DiskWriterEntry*> DiskWriterEntries;

class MultiDiskWriter : public DiskWriter {
private:
  DiskWriterEntries diskWriterEntries;
  int pieceLength;
  bool isInRange(const DiskWriterEntry* entry, long long int offset) const;
  int calculateLength(const DiskWriterEntry* entry, long long int fileOffset, int rem) const;
  void clearEntries();
#ifdef ENABLE_MESSAGE_DIGEST
  MessageDigestContext ctx;
  void hashUpdate(DiskWriterEntry* entry, long long int offset, long long int length);
#endif // ENABLE_MESSAGE_DIGEST

public:
  MultiDiskWriter(int pieceLength);
  virtual ~MultiDiskWriter();

  void setFileEntries(const FileEntries& fileEntries);

  virtual void openFile(const string& filename);
  virtual void initAndOpenFile(const string& filename);
  virtual void closeFile();
  virtual void openExistingFile(const string& filename);
  virtual void writeData(const char* data, int len, long long int position = 0);
  virtual int readData(char* data, int len, long long int position);
  virtual string sha1Sum(long long int offset, long long int length);
};

#endif // _D_MULTI_DISK_WRITER_H_
